package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ZyCategory;

/**
 * 栏目管理Service接口
 * 
 * @author libao
 * @date 2024-05-24
 */
public interface IZyCategoryService 
{
    /**
     * 查询栏目管理
     * 
     * @param id 栏目管理主键
     * @return 栏目管理
     */
    public ZyCategory selectZyCategoryById(Long id);

    /**
     * 查询栏目管理列表
     * 
     * @param zyCategory 栏目管理
     * @return 栏目管理集合
     */
    public List<ZyCategory> selectZyCategoryList(ZyCategory zyCategory);

    /**
     * 新增栏目管理
     * 
     * @param zyCategory 栏目管理
     * @return 结果
     */
    public int insertZyCategory(ZyCategory zyCategory);

    /**
     * 修改栏目管理
     * 
     * @param zyCategory 栏目管理
     * @return 结果
     */
    public int updateZyCategory(ZyCategory zyCategory);

    /**
     * 批量删除栏目管理
     * 
     * @param ids 需要删除的栏目管理主键集合
     * @return 结果
     */
    public int deleteZyCategoryByIds(Long[] ids);

    /**
     * 删除栏目管理信息
     * 
     * @param id 栏目管理主键
     * @return 结果
     */
    public int deleteZyCategoryById(Long id);
}
