package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ZyCategory;
import com.ruoyi.system.service.IZyCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 栏目管理Controller
 * 
 * @author libao
 * @date 2024-05-24
 */
@RestController
@RequestMapping("/system/category")
public class ZyCategoryController extends BaseController
{
    @Autowired
    private IZyCategoryService zyCategoryService;

    /**
     * 查询栏目管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:category:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZyCategory zyCategory)
    {
        startPage();
        List<ZyCategory> list = zyCategoryService.selectZyCategoryList(zyCategory);
        return getDataTable(list);
    }

    /**
     * 导出栏目管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:category:export')")
    @Log(title = "栏目管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZyCategory zyCategory)
    {
        List<ZyCategory> list = zyCategoryService.selectZyCategoryList(zyCategory);
        ExcelUtil<ZyCategory> util = new ExcelUtil<ZyCategory>(ZyCategory.class);
        util.exportExcel(response, list, "栏目管理数据");
    }

    /**
     * 获取栏目管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:category:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zyCategoryService.selectZyCategoryById(id));
    }

    /**
     * 新增栏目管理
     */
    @PreAuthorize("@ss.hasPermi('system:category:add')")
    @Log(title = "栏目管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZyCategory zyCategory)
    {
        return toAjax(zyCategoryService.insertZyCategory(zyCategory));
    }

    /**
     * 修改栏目管理
     */
    @PreAuthorize("@ss.hasPermi('system:category:edit')")
    @Log(title = "栏目管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZyCategory zyCategory)
    {
        return toAjax(zyCategoryService.updateZyCategory(zyCategory));
    }

    /**
     * 删除栏目管理
     */
    @PreAuthorize("@ss.hasPermi('system:category:remove')")
    @Log(title = "栏目管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zyCategoryService.deleteZyCategoryByIds(ids));
    }
}
